@@ -9,7 +9,7 @@ https://github.com/Saadmairaj/tkmacosx/tree/master/tkmacosx.
 """
 
 from tkmacosx.basewidget import check_appearence, get_shade
-from tkmacosx.variables import ColorVar, DictVar, demo_colorvar
+from tkmacosx.variables import ColorVar, DictVar, demo_colorvar, SaveVar, demo_savevar
 from tkmacosx.widget import Button, SFrame, demo_sframe, demo_button
 from tkmacosx.colors import Hex, OrderedHex
 from tkmacosx.colorscale import Colorscale, demo_colorscale
@@ -18,3 +18,4 @@ if __name__ == "__main__":
     demo_sframe()
     demo_button()
     demo_colorvar()
+    demo_colorscale()
